@@ -4,13 +4,16 @@ from d2b import d2b
 from d2b import defaults
 from d2b import hookspecs
 from d2b import plugins
+from d2b import scaffold
 from d2b.d2b import __version__
 from d2b.d2b import Acquisition
 from d2b.d2b import D2B
 from d2b.d2b import Description
 from d2b.d2b import FilenameEntities
+from d2b.d2b import IntendedForResolver
 from d2b.d2b import Matcher
 from d2b.d2b import Participant
+from d2b.scaffold import DatasetDescription
 
 
 __all__ = (
@@ -20,11 +23,14 @@ __all__ = (
     "defaults",
     "hookspecs",
     "plugins",
+    "scaffold",
     "__version__",
     "Acquisition",
     "D2B",
     "Description",
     "FilenameEntities",
+    "IntendedForResolver",
     "Matcher",
     "Participant",
+    "DatasetDescription",
 )
