@@ -9,6 +9,7 @@ from typing import TYPE_CHECKING
 from d2b import defaults
 from d2b.hookspecs import hookimpl
 from d2b.utils import compare
+from d2b.utils import filepath_sort_key
 from d2b.utils import first_nii
 from d2b.utils import splitext
 
@@ -30,6 +31,11 @@ def collect_files(d2b_dir: Path) -> list[Path]:
     return list(d2b_dir.rglob("*.json"))
 
 
+@hookimpl(tryfirst=True)
+def prepare_collected_files(files: list[Path]) -> None:
+    files.sort(key=filepath_sort_key)
+
+
 @hookimpl
 def is_link(
     path: Path,
@@ -53,6 +59,10 @@ def is_link(
             # check the file name of the sidecar
             result.append(compare(path.name, pattern, search_method, case_sensitive))
 
+        elif tag == "filepath" or tag == "SidecarFilepath":
+            # check the _path_ of the file (this can included )
+            result.append(compare(str(path), pattern, search_method, case_sensitive))
+
         elif isinstance(tagValue, list) and isinstance(pattern, list):
             # check that there's a bijective mapping between the two lists
             matching_length = len(tagValue) == len(pattern)
