@@ -17,11 +17,28 @@ for plugin in DEFAULT_PLUGINS:
 
 
 def get_plugins():
+    """Get all the resgistered plugins
+
+    Examples:
+        >>> from pprint import pp
+        >>> plugins = get_plugins()
+        >>> pp(sorted([tuple(sorted(p.items())) for p in plugins]))
+        [(('hooks',
+           ['collect_files',
+            'is_link',
+            'load_config',
+            'move',
+            'pre_move',
+            'prepare_collected_files']),
+          ('name', 'd2b.internal_plugins.core')),
+         (('hooks', ['register_commands']), ('name', 'd2b.commands.scaffold'))]
+    """
     plugins = []
     plugin_to_distinfo = dict(pm.list_plugin_distinfo())
     for plugin in pm.get_plugins():
         hook_callers = pm.get_hookcallers(plugin)
         if hook_callers is None:
+            # this registered plugin doesn't implement any hooks
             continue
         plugin_info = {
             "name": plugin.__name__,
